@@ -248,9 +248,9 @@ class IotToLambdaProps:
         :summary: The properties for the IotToLambda class.
         '''
         if isinstance(iot_topic_rule_props, dict):
-            iot_topic_rule_props = CfnTopicRuleProps(**iot_topic_rule_props)
+            iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = FunctionProps(**lambda_function_props)
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if __debug__:
             type_hints = typing.get_type_hints(IotToLambdaProps.__init__)
             check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
